/*
 * CIM Repository Interface
 *
 * This is the interface that any CIM Repository can be written to
 * plug into the WBEM Solutions J WBEM Server
 *
 * Copyright (c) 2003 - 2004 WBEM Solutions, Inc. All rights reserved.
 * WBEM SOLUTIONS PROPRIETARY/CONFIDENTIAL. Use is subject to license terms. 
 */
package com.wbemsolutions.wbem.cimom.repository;

import javax.wbem.cim.CIMClass;
import javax.wbem.cim.CIMException;
import javax.wbem.cim.CIMObjectPath;
import javax.wbem.cim.CIMQualifierType;


/**
 * CIM Repository Interface
 *
 *  This interface is what is implemented to create a CIM Repository for the
 *  WBEM Solutions J WBEM Server.
 * 
 * It is broken down into the following sections....
 *  
 * @author Jim Davis
 */
public interface CIMRepository {

	/**
	 * Create the specified namespace
	 *
	 * @param op    name of  namespace that needs to be created.
	 */
	public void createNamespace(CIMObjectPath op) throws CIMException;

	/**
	 * Delete the specified namespace
	 *
	 * @param op    name of namespace that needs to be deleted
	 */
	public void deleteNamespace(CIMObjectPath op) throws CIMException;

	/**
	 * Enumerate the specified namespace
	 *
	 * @return String[]    list of name of namespaces
	 */
	public String[] enumerateNamespaces() throws CIMException;

	/**
	 * Create a qualifierType in the specified namespace
	 *
	 * @param op  name of namespace that contains this qualifier
	 * @param qt         the qualifier to be added
	 */
	public void createQualifierType(CIMObjectPath op, CIMQualifierType qt)
		throws CIMException;

	/**
	 * Delete a qualifierType
	 *
	 * @param op    the CIMObjectPath of this qualifier
	 */
	public void deleteQualifierType(CIMObjectPath op) throws CIMException;

	/**
	 * Enumerate the qualifierTypes in a namespace
	 *
	 * @param op        the CIMObjectPath of the namespace
	 * @return CIMQualifierType[]   Array of CIMQualifierTypes 
	 */
	public CIMQualifierType[] enumerateQualifierTypes(CIMObjectPath op)
		throws CIMException;

	/**
	 * Get the qualifierType specified by the CIMObjectPath
	 *
	 * @param op                    the CIMObjectPath of this qualifier
	 * @return CIMQualifierType     CIMQualifierType object
	 */
	public CIMQualifierType getQualifierType(CIMObjectPath op)
		throws CIMException;

	/**
	 * Replace the existing qualifier with the specified one
	 *
	 * @param op    name of namespace that contains this qualifier
	 * @param qt    the new qualifier to be added
	 */
	public void setQualifierType(CIMObjectPath op, CIMQualifierType qt)
		throws CIMException;

	/**
	 * Create a class in the specified namespace
	 *
	 * @param op    name of namespace that contains this class
	 * @param cc           the class to be created
	 */
	public void createClass(CIMObjectPath op, CIMClass cc) throws CIMException;

	/**
	 * Delete the specified class
	 *
	 * @param op    the CIMObjectPath of this class
	 */
	public void deleteClass(CIMObjectPath op) throws CIMException;

	/**
	 * Retrieve the class that specified by the CIMObjectPath
	 *
	 * @param op    the CIMObjectPath of this class
	 * @return CIMClass    the retrived CIMClass object
	 */
	public CIMClass getClass(CIMObjectPath op) throws CIMException;

	/**
	 * Enumerate class names
	 *
	 * @param op        the CIMObjectPath of the class to start the enumeration
	 * @param deep      true for all subclasses, false for one level down
	 * @return CIMObjectPath[]   Array of CIMObjectPaths
	 */
	public CIMObjectPath[] enumerateClassNames(CIMObjectPath op, boolean deep)
            throws CIMException;

	/**
	 * Enumerate classes of the specified class
	 *
	 * @param op        the CIMObjectPath of this class
	 * @param deep      true for all subclasses, false for one level down
	 * @param localonly    true for class contains only local elements
	 * @return CIMClass[]   list of CIMClass of classes
	 */
	public CIMClass[] enumerateClasses(CIMObjectPath op, boolean deep,
            boolean localonly, boolean iq, boolean ico) throws CIMException;

	/**
	 * Modify the existing class with the specified one
	 *
	 * @param op    name of namespace that contains this class
	 * @param cc           the class information to be modified
	 * 
	 */
	public void modifyClass(CIMObjectPath op, CIMClass cc) throws CIMException;
        
}
